/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: CommonMetadataConfigurator.java 6167 2012-02-09 16:46:06Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.common.impl.configurator;

import java.util.Map;

import org.ow2.util.ee.metadata.common.api.interfaces.ISharedMetadata;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.JavaxAnnotationResourceVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.JavaxEjbEJBVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.JavaxJwsHandlerChainVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.JavaxPersistencePersistenceContextVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.JavaxPersistencePersistenceUnitVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.JavaxXmlWsWebServiceRefVisitor;
import org.ow2.util.scan.api.IAnnotationVisitor;

/**
 * Utility class.
 * @author Gael Lalire
 */
public final class CommonMetadataConfigurator {

    /**
     * Constructor.
     */
    private CommonMetadataConfigurator() {
    }

    /**
     * @param <T> type
     * @param annotationVisitors annotationVisitors
     * @param annotationMetadata am
     */
    public static <T extends ISharedMetadata> void initVisitor(final Map<String, IAnnotationVisitor> annotationVisitors,
            final T annotationMetadata) {

        // add @EJB
        annotationVisitors.put(JavaxEjbEJBVisitor.TYPE, new JavaxEjbEJBVisitor<T>(annotationMetadata));

        // add @Resource
        annotationVisitors.put(JavaxAnnotationResourceVisitor.TYPE, new JavaxAnnotationResourceVisitor<T>(annotationMetadata));

        // add @PersistenceContext
        annotationVisitors.put(JavaxPersistencePersistenceContextVisitor.TYPE, new JavaxPersistencePersistenceContextVisitor<T>(
                annotationMetadata));

        // add @PersistenceUnit
        annotationVisitors.put(JavaxPersistencePersistenceUnitVisitor.TYPE, new JavaxPersistencePersistenceUnitVisitor<T>(
                annotationMetadata));

        // add @WebServiceRef
        annotationVisitors.put(JavaxXmlWsWebServiceRefVisitor.TYPE,
                               new JavaxXmlWsWebServiceRefVisitor<T>(annotationMetadata));

        // add @HandlerChain
        annotationVisitors.put(JavaxJwsHandlerChainVisitor.TYPE,
                               new JavaxJwsHandlerChainVisitor<T>(annotationMetadata));

    }

}
