/**
 * EasyBeans
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: PortComponentRef.java 4706 2009-02-25 13:24:59Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.common.impl.xml.struct;

import java.util.Properties;

import org.ow2.util.ee.metadata.common.api.xml.struct.IPortComponentRef;

/**
 * This class defines the implementation of the &lt;port-component-ref&gt; element.
 * @author Guillaume Sauthier
 */
public class PortComponentRef implements IPortComponentRef {

    /**
     * Serial version UID.
     */
    private static final long serialVersionUID = -8508665352218354998L;

    /**
     * Service Endpoint Interface of the &lt;port-component-ref&gt; element.
     */
    private String serviceEndpointInterface = null;

    /**
     * Is MTOM enabled of the &lt;port-component-ref&gt; element.
     */
    private boolean enableMTOM = false;

    /**
     * PortComponent link of the &lt;port-component-ref&gt; element.
     */
    private String portComponentLink = null;

    /**
     * Stub properties.
     */
    private Properties stubProperties = null;

    /**
     * Default constructor.
     */
    public PortComponentRef() {
        this.stubProperties = new Properties();
    }



    public boolean isEnableMTOM() {
        return enableMTOM;
    }

    public void setEnableMTOM(final boolean enableMTOM) {
        this.enableMTOM = enableMTOM;
    }

    public String getPortComponentLink() {
        return portComponentLink;
    }

    public void setPortComponentLink(final String portComponentLink) {
        this.portComponentLink = portComponentLink;
    }

    public String getServiceEndpointInterface() {
        return serviceEndpointInterface;
    }

    public void setServiceEndpointInterface(final String serviceEndpointInterface) {
        this.serviceEndpointInterface = serviceEndpointInterface;
    }

    /**
     * Sets stub properties.
     * @param stubProperties the given properties
     */
    public void setStubProperties(final Properties stubProperties) {
        this.stubProperties = stubProperties;
    }

    /**
     * @return stub properties
     */
    public Properties getStubProperties() {
        return stubProperties;
    }
}
